@@ -1227,6 +1227,8 @@ get_filename_for_size (GnomeBG *bg, gint best_width, gint best_height)
 	}
 
         gnome_bg_slide_show_get_current_slide (show, best_width, best_height, NULL, NULL, NULL, &file, NULL);
+        g_object_unref (show);
+
         return file;
 }
 
@@ -2609,14 +2611,20 @@ gboolean
 gnome_bg_changes_with_time (GnomeBG *bg)
 {
 	GnomeBGSlideShow *show;
+	gboolean ret = FALSE;
 
 	g_return_val_if_fail (bg != NULL, FALSE);
 
-	show = get_as_slideshow (bg, bg->filename);
-	if (show)
-		return gnome_bg_slide_show_get_num_slides (show) > 1;
+	if (!bg->filename)
+		return FALSE;
 
-	return FALSE;
+	show = get_as_slideshow (bg, bg->filename);
+	if (show) {
+		ret = gnome_bg_slide_show_get_num_slides (show) > 1;
+		g_object_unref (show);
+	}
+
+	return ret;
 }
 
 /**
@@ -2640,7 +2648,6 @@ gnome_bg_create_frame_thumbnail (GnomeBG			*bg,
 	GnomeBGSlideShow *show;
 	GdkPixbuf *result;
 	GdkPixbuf *thumb;
-        GList *l;
         int skipped;
         gboolean is_fixed;
 
